%% Fig 2 a
[img, map] = imread('fig_2_a\TKH_56_CSD.png'); % import .png file % 
R=img(:,:,1);
G=img(:,:,2);
B=img(:,:,3);
img_grey = 0.3*R+0.6*G+0.1*B;
img_grey(:,749:779)=[];
img_grey(:,1:77)=[];
img_grey(540:600,:)=[];
img_grey(1:53,:)=[];
x_slope=0.2047; %slope for img_grey(100,:)
y_slope=-0.7627; %slope for img_grey(:,100)
img_bg=zeros(486,671);
for x_ii=1:486
    for y_ii=1:671
        img_bg(x_ii,y_ii)=y_slope*x_ii+x_slope*y_ii;
    end
end
img_processed=double(img_grey)-img_bg;
img_processed=(img_processed-100)*255/350;
img_processed=uint8(img_processed);
figure
imagesc([-12,13],[13,-12],img_processed)
set(gca,'YDir','normal')
colormap(gray)
xlabel('$\Delta P^{\prime}_2$ (mV)','Interpreter','latex','FontSize',22)
ylabel('$\Delta P^{\prime}_3$ (mV)','Interpreter','latex','FontSize',22)
%% Fig 2 b
KT = 12.6; % temperature in ueV
tc_guess = [8.9,24.5,43.6]; % tunnel coupling in ueV
excess_charge_data = importdata('fig_2_b\excess_charge_data.txt');
figure
hold on
for ii=1:3
    x = excess_charge_data(:,2*ii-1);
    y = excess_charge_data(:,2*ii);

    s = fitoptions('Method','NonlinearLeastSquares',...
        'Lower',[5,KT],...
        'Upper',[50,KT],...
        'Startpoint',[40,KT]);
    formula='excess_charge(x,tc,KT)';
    f = fittype(formula,'dependent',{'y'},...
        'independent',{'x'},'coefficients',{'tc','KT'},'options', s);
    gfit = fit(x,y,f);
    dot_plot = plot(x,y,'.','MarkerSize',10);
    dot_plot.DisplayName=['$t=',num2str(gfit.tc),'$'];
    fit_plot = plot(x,excess_charge(x,gfit.tc,KT),'k');
    set(fit_plot,'HandleVisibility','off')
end
hold off
xlim([-200,200])
lg = legend;
lg.Interpreter='latex';
xlabel(['Detuning, \epsilon (',char(181),'eV)'],'Interpreter','tex','FontSize',22)
ylabel('Excess charge','FontSize',22)
%% Fig 2 c
exp_curve_data = importdata('fig_2_c\exp_curve_data.txt');
b_guess = [5,50,20;-25,-5,-10];
sub_idx = [12,23];
figure
hold on
for ii=1:2
    x = exp_curve_data(:,2*ii-1);
    y = exp_curve_data(:,2*ii);

    s = fitoptions('Method','NonlinearLeastSquares',...
        'Lower',[5,b_guess(ii,1)],...
        'Upper',[40,b_guess(ii,2)],...
        'Startpoint',[19,b_guess(ii,3)]);
    formula='a*exp(-x/b)';
    f = fittype(formula,'dependent',{'y'},...
        'independent',{'x'},'coefficients',{'a','b'},'options', s);
    gfit = fit(x,y,f);
    dot_plot = plot(x,y,'.','MarkerSize',10);
    dot_plot.DisplayName=['$B^{\prime}_{',num2str(sub_idx(ii)),'}$'];
    fit_plot = plot(x,gfit.a*exp(-x/gfit.b),':k');
    set(fit_plot,'HandleVisibility','off')
end
hold off
xlim([-25,25])
lg = legend;
lg.Interpreter='latex';
xlabel('$\Delta B^{\prime}_{ij}$ (mV)','Interpreter','latex','FontSize',22)
ylabel(['{\it{t}}_{23} (',char(181),'eV)'],'Interpreter','tex','FontSize',22);
%% Fig 2 d
lin_curve_data = importdata('fig_2_d\lin_curve_data.txt');
sub_idx = [12,23];
figure
hold on
for ii=1:2
    x = lin_curve_data(:,1);
    y = lin_curve_data(:,ii+1);

    fit_result=polyfit(x,y,1);
    fit_line=x*fit_result(1)+fit_result(2);
    dot_plot = plot(x,y,'.','MarkerSize',10);
    dot_plot.DisplayName=['$B^{\prime}_{',num2str(sub_idx(ii)),'}$'];
    fit_plot = plot(x,fit_line,':k');
    set(fit_plot,'HandleVisibility','off')
end
hold off
xlim([-5.5,5.5])
lg = legend;
lg.Interpreter='latex';
xlabel('$\Delta B^{\prime}_{ij}$ (mV)','Interpreter','latex','FontSize',22)
ylabel(['{\it{t}}_{23} (',char(181),'eV)'],'Interpreter','tex','FontSize',22);

%% Fig 3 a
xy_data = importdata('fig_3_a\t12_before_calibration.txt');
figure
hold on
plt_obj_all=[];
lin_fit_slope=[];
lin_fit_slope_error=[];
color_array=[0.85,0.325,0.098;0.93,0.694,0.125;0.494,0.184,0.557];
sub_idx_array=[12,23,34];
for ii=1:3
    x_data=xy_data(:,1);
    y_data=xy_data(:,ii+1);
    fit_result=polyfit(x_data,y_data,1);
    fit_line=x_data*fit_result(1)+fit_result(2);
    % calculate slope error
    data_number=length(x_data);
    x_data_mean=mean(x_data);
    tmp_1=(x_data-x_data_mean).^2;
    sum_tmp_1=sum(tmp_1);
    tmp_2=(y_data-fit_line).^2;
    sum_tmp_2=sum(tmp_2);
    slope_std_error=(sum_tmp_2/sum_tmp_1/(data_number-2))^0.5;
    
    lin_fit_slope=[lin_fit_slope,fit_result(1)];
    lin_fit_slope_error=[lin_fit_slope_error,slope_std_error];
    % filled marker
    plt_obj=plot(x_data,y_data,'o','MarkerSize',5,'LineWidth',2,'Color',color_array(ii,:),'MarkerFaceColor',color_array(ii,:));
    % unfilled marker
    %plt_obj=plot(x_data,y_data,'o','MarkerSize',5,'LineWidth',2,'Color',color_array(ii,:));

    plt_obj.DisplayName=['$B^{\prime}_{',num2str(sub_idx_array(ii)),'}$'];
    %plt_obj.DisplayName=['$B^{\dagger}_{',num2str(sub_idx_array(ii)),'}$'];
    plt_obj_all=[plt_obj_all,plt_obj];
    current_color=get(plt_obj,'Color');
    plot(x_data,fit_line,'--','LineWidth',2,'Color',current_color)
end
hold off
lg=legend(plt_obj_all);
lg.Interpreter='latex';
lg.FontSize=20;
lg.Orientation='horizontal';
lg.Location='northwest';
ax1 = gca; % current axes
ax1.FontSize=20;
box on
xlabel('$\Delta B^{\prime}_{ij}$ (mV)','Interpreter','latex','FontSize',22)
%xlabel('$\Delta B^{\dagger}_{ij}$ (mV)','Interpreter','latex','FontSize',22)
ylabel(['{\it{t}}_{12} (',char(181),'eV)'],'Interpreter','tex','FontSize',22);
%% Fig 3 b
xy_data = importdata('fig_3_b\t23_before_calibration.txt');
figure
hold on
plt_obj_all=[];
lin_fit_slope=[];
lin_fit_slope_error=[];
color_array=[0.85,0.325,0.098;0.93,0.694,0.125;0.494,0.184,0.557];
sub_idx_array=[12,23,34];
for ii=1:3
    x_data=xy_data(:,1);
    y_data=xy_data(:,ii+1);
    fit_result=polyfit(x_data,y_data,1);
    fit_line=x_data*fit_result(1)+fit_result(2);
    % calculate slope error
    data_number=length(x_data);
    x_data_mean=mean(x_data);
    tmp_1=(x_data-x_data_mean).^2;
    sum_tmp_1=sum(tmp_1);
    tmp_2=(y_data-fit_line).^2;
    sum_tmp_2=sum(tmp_2);
    slope_std_error=(sum_tmp_2/sum_tmp_1/(data_number-2))^0.5;
    
    lin_fit_slope=[lin_fit_slope,fit_result(1)];
    lin_fit_slope_error=[lin_fit_slope_error,slope_std_error];
    % filled marker
    plt_obj=plot(x_data,y_data,'o','MarkerSize',5,'LineWidth',2,'Color',color_array(ii,:),'MarkerFaceColor',color_array(ii,:));
    % unfilled marker
    %plt_obj=plot(x_data,y_data,'o','MarkerSize',5,'LineWidth',2,'Color',color_array(ii,:));

    plt_obj.DisplayName=['$B^{\prime}_{',num2str(sub_idx_array(ii)),'}$'];
    %plt_obj.DisplayName=['$B^{\dagger}_{',num2str(sub_idx_array(ii)),'}$'];
    plt_obj_all=[plt_obj_all,plt_obj];
    current_color=get(plt_obj,'Color');
    plot(x_data,fit_line,'--','LineWidth',2,'Color',current_color)
end
hold off
lg=legend(plt_obj_all);
lg.Interpreter='latex';
lg.FontSize=20;
lg.Orientation='horizontal';
lg.Location='northwest';
ax1 = gca; % current axes
ax1.FontSize=20;
box on
xlabel('$\Delta B^{\prime}_{ij}$ (mV)','Interpreter','latex','FontSize',22)
%xlabel('$\Delta B^{\dagger}_{ij}$ (mV)','Interpreter','latex','FontSize',22)
ylabel(['{\it{t}}_{23} (',char(181),'eV)'],'Interpreter','tex','FontSize',22);
%% Fig 3 c
xy_data = importdata('fig_3_c\t34_before_calibration.txt');
figure
hold on
plt_obj_all=[];
lin_fit_slope=[];
lin_fit_slope_error=[];
color_array=[0.85,0.325,0.098;0.93,0.694,0.125;0.494,0.184,0.557];
sub_idx_array=[12,23,34];
for ii=1:3
    x_data=xy_data(:,1);
    y_data=xy_data(:,ii+1);
    fit_result=polyfit(x_data,y_data,1);
    fit_line=x_data*fit_result(1)+fit_result(2);
    % calculate slope error
    data_number=length(x_data);
    x_data_mean=mean(x_data);
    tmp_1=(x_data-x_data_mean).^2;
    sum_tmp_1=sum(tmp_1);
    tmp_2=(y_data-fit_line).^2;
    sum_tmp_2=sum(tmp_2);
    slope_std_error=(sum_tmp_2/sum_tmp_1/(data_number-2))^0.5;
    
    lin_fit_slope=[lin_fit_slope,fit_result(1)];
    lin_fit_slope_error=[lin_fit_slope_error,slope_std_error];
    % filled marker
    plt_obj=plot(x_data,y_data,'o','MarkerSize',5,'LineWidth',2,'Color',color_array(ii,:),'MarkerFaceColor',color_array(ii,:));
    % unfilled marker
    %plt_obj=plot(x_data,y_data,'o','MarkerSize',5,'LineWidth',2,'Color',color_array(ii,:));

    plt_obj.DisplayName=['$B^{\prime}_{',num2str(sub_idx_array(ii)),'}$'];
    %plt_obj.DisplayName=['$B^{\dagger}_{',num2str(sub_idx_array(ii)),'}$'];
    plt_obj_all=[plt_obj_all,plt_obj];
    current_color=get(plt_obj,'Color');
    plot(x_data,fit_line,'--','LineWidth',2,'Color',current_color)
end
hold off
lg=legend(plt_obj_all);
lg.Interpreter='latex';
lg.FontSize=20;
lg.Orientation='horizontal';
lg.Location='northwest';
ax1 = gca; % current axes
ax1.FontSize=20;
box on
xlabel('$\Delta B^{\prime}_{ij}$ (mV)','Interpreter','latex','FontSize',22)
%xlabel('$\Delta B^{\dagger}_{ij}$ (mV)','Interpreter','latex','FontSize',22)
ylabel(['{\it{t}}_{34} (',char(181),'eV)'],'Interpreter','tex','FontSize',22);
%% Fig 3 d
xy_data = importdata('fig_3_d\t12_after_calibration.txt');
figure
hold on
plt_obj_all=[];
lin_fit_slope=[];
lin_fit_slope_error=[];
color_array=[0.85,0.325,0.098;0.93,0.694,0.125;0.494,0.184,0.557];
sub_idx_array=[12,23,34];
for ii=1:3
    x_data=xy_data(:,1);
    y_data=xy_data(:,ii+1);
    fit_result=polyfit(x_data,y_data,1);
    fit_line=x_data*fit_result(1)+fit_result(2);
    % calculate slope error
    data_number=length(x_data);
    x_data_mean=mean(x_data);
    tmp_1=(x_data-x_data_mean).^2;
    sum_tmp_1=sum(tmp_1);
    tmp_2=(y_data-fit_line).^2;
    sum_tmp_2=sum(tmp_2);
    slope_std_error=(sum_tmp_2/sum_tmp_1/(data_number-2))^0.5;
    
    lin_fit_slope=[lin_fit_slope,fit_result(1)];
    lin_fit_slope_error=[lin_fit_slope_error,slope_std_error];
    % filled marker
    %plt_obj=plot(x_data,y_data,'o','MarkerSize',5,'LineWidth',2,'Color',color_array(ii,:),'MarkerFaceColor',color_array(ii,:));
    % unfilled marker
    plt_obj=plot(x_data,y_data,'o','MarkerSize',5,'LineWidth',2,'Color',color_array(ii,:));

    %plt_obj.DisplayName=['$B^{\prime}_{',num2str(sub_idx_array(ii)),'}$'];
    plt_obj.DisplayName=['$B^{\dagger}_{',num2str(sub_idx_array(ii)),'}$'];
    plt_obj_all=[plt_obj_all,plt_obj];
    current_color=get(plt_obj,'Color');
    plot(x_data,fit_line,'--','LineWidth',2,'Color',current_color)
end
hold off
lg=legend(plt_obj_all);
lg.Interpreter='latex';
lg.FontSize=20;
lg.Orientation='horizontal';
lg.Location='northwest';
ax1 = gca; % current axes
ax1.FontSize=20;
box on
%xlabel('$\Delta B^{\prime}_{ij}$ (mV)','Interpreter','latex','FontSize',22)
xlabel('$\Delta B^{\dagger}_{ij}$ (mV)','Interpreter','latex','FontSize',22)
ylabel(['{\it{t}}_{12} (',char(181),'eV)'],'Interpreter','tex','FontSize',22);
%% Fig 3 e
xy_data = importdata('fig_3_e\t23_after_calibration.txt');
figure
hold on
plt_obj_all=[];
lin_fit_slope=[];
lin_fit_slope_error=[];
color_array=[0.85,0.325,0.098;0.93,0.694,0.125;0.494,0.184,0.557];
sub_idx_array=[12,23,34];
for ii=1:3
    x_data=xy_data(:,1);
    y_data=xy_data(:,ii+1);
    fit_result=polyfit(x_data,y_data,1);
    fit_line=x_data*fit_result(1)+fit_result(2);
    % calculate slope error
    data_number=length(x_data);
    x_data_mean=mean(x_data);
    tmp_1=(x_data-x_data_mean).^2;
    sum_tmp_1=sum(tmp_1);
    tmp_2=(y_data-fit_line).^2;
    sum_tmp_2=sum(tmp_2);
    slope_std_error=(sum_tmp_2/sum_tmp_1/(data_number-2))^0.5;
    
    lin_fit_slope=[lin_fit_slope,fit_result(1)];
    lin_fit_slope_error=[lin_fit_slope_error,slope_std_error];
    % filled marker
    %plt_obj=plot(x_data,y_data,'o','MarkerSize',5,'LineWidth',2,'Color',color_array(ii,:),'MarkerFaceColor',color_array(ii,:));
    % unfilled marker
    plt_obj=plot(x_data,y_data,'o','MarkerSize',5,'LineWidth',2,'Color',color_array(ii,:));

    %plt_obj.DisplayName=['$B^{\prime}_{',num2str(sub_idx_array(ii)),'}$'];
    plt_obj.DisplayName=['$B^{\dagger}_{',num2str(sub_idx_array(ii)),'}$'];
    plt_obj_all=[plt_obj_all,plt_obj];
    current_color=get(plt_obj,'Color');
    plot(x_data,fit_line,'--','LineWidth',2,'Color',current_color)
end
hold off
lg=legend(plt_obj_all);
lg.Interpreter='latex';
lg.FontSize=20;
lg.Orientation='horizontal';
lg.Location='northwest';
ax1 = gca; % current axes
ax1.FontSize=20;
box on
%xlabel('$\Delta B^{\prime}_{ij}$ (mV)','Interpreter','latex','FontSize',22)
xlabel('$\Delta B^{\dagger}_{ij}$ (mV)','Interpreter','latex','FontSize',22)
ylabel(['{\it{t}}_{23} (',char(181),'eV)'],'Interpreter','tex','FontSize',22);
%% Fig 3 f
xy_data = importdata('fig_3_f\t34_after_calibration.txt');
figure
hold on
plt_obj_all=[];
lin_fit_slope=[];
lin_fit_slope_error=[];
color_array=[0.85,0.325,0.098;0.93,0.694,0.125;0.494,0.184,0.557];
sub_idx_array=[12,23,34];
for ii=1:3
    x_data=xy_data(:,1);
    y_data=xy_data(:,ii+1);
    fit_result=polyfit(x_data,y_data,1);
    fit_line=x_data*fit_result(1)+fit_result(2);
    % calculate slope error
    data_number=length(x_data);
    x_data_mean=mean(x_data);
    tmp_1=(x_data-x_data_mean).^2;
    sum_tmp_1=sum(tmp_1);
    tmp_2=(y_data-fit_line).^2;
    sum_tmp_2=sum(tmp_2);
    slope_std_error=(sum_tmp_2/sum_tmp_1/(data_number-2))^0.5;
    
    lin_fit_slope=[lin_fit_slope,fit_result(1)];
    lin_fit_slope_error=[lin_fit_slope_error,slope_std_error];
    % filled marker
    %plt_obj=plot(x_data,y_data,'o','MarkerSize',5,'LineWidth',2,'Color',color_array(ii,:),'MarkerFaceColor',color_array(ii,:));
    % unfilled marker
    plt_obj=plot(x_data,y_data,'o','MarkerSize',5,'LineWidth',2,'Color',color_array(ii,:));

    %plt_obj.DisplayName=['$B^{\prime}_{',num2str(sub_idx_array(ii)),'}$'];
    plt_obj.DisplayName=['$B^{\dagger}_{',num2str(sub_idx_array(ii)),'}$'];
    plt_obj_all=[plt_obj_all,plt_obj];
    current_color=get(plt_obj,'Color');
    plot(x_data,fit_line,'--','LineWidth',2,'Color',current_color)
end
hold off
lg=legend(plt_obj_all);
lg.Interpreter='latex';
lg.FontSize=20;
lg.Orientation='horizontal';
lg.Location='northwest';
ax1 = gca; % current axes
ax1.FontSize=20;
box on
%xlabel('$\Delta B^{\prime}_{ij}$ (mV)','Interpreter','latex','FontSize',22)
xlabel('$\Delta B^{\dagger}_{ij}$ (mV)','Interpreter','latex','FontSize',22)
ylabel(['{\it{t}}_{34} (',char(181),'eV)'],'Interpreter','tex','FontSize',22);
%% Fig 4 a
data_exp_curve=importdata('fig_4_a\fig4_exp_curve_data.txt');
data_crosstalk=importdata('fig_4_a\t23_with_different_b12.txt');
x_data_combine=[];
y_data_combine=[];
figure
hold on
plt_obj_all=[];
for ii=1:6
    plt_obj=plot(data_exp_curve(:,1),transpose(data_crosstalk(ii,2:end)),'o','MarkerSize',5,'LineWidth',2);
    plt_obj.DisplayName=['$\Delta B^{\dagger}_{12}=$',num2str(-10+(ii-1)*4)];
    plt_obj_all=[plt_obj_all,plt_obj];
end
plt_obj_0=plot(data_exp_curve(:,1),data_exp_curve(:,2),'o','MarkerSize',5,'LineWidth',2,'Color','k');
plt_obj_0.DisplayName='$\Delta B^{\dagger}_{12}=$0';
for ii=1:6
    x_data_combine=[x_data_combine;data_exp_curve(:,1)];
    y_data_combine=[y_data_combine;transpose(data_crosstalk(ii,2:end))];
end
x_data_combine=[x_data_combine;data_exp_curve(:,1)];
y_data_combine=[y_data_combine;data_exp_curve(:,2)];
s = fitoptions('Method','NonlinearLeastSquares',...
    'Lower',[5,5,0],...
    'Upper',[40,40,15],...
    'Startpoint',[25,25,5]);
formula='a*exp((x)/b)+c';
f = fittype(formula,'dependent',{'y'},...
    'independent',{'x'},'coefficients',{'a','b','c'},'options', s);
gfit = fit(x_data_combine,y_data_combine,f);
data_combine_exp_fit_x=[-12.5:0.1:17.5];
data_combine_exp_fit=[data_combine_exp_fit_x;gfit.a*exp((data_combine_exp_fit_x)/gfit.b)+gfit.c];
data_combine_exp_fit=transpose(data_combine_exp_fit);
plot(data_combine_exp_fit(:,1),data_combine_exp_fit(:,2),':','LineWidth',2)
hold off
ax1=gca;
ax1.Box='on';
ax1.FontSize=20;
lg=legend([plt_obj_all(1:3),plt_obj_0,plt_obj_all(4:6)]);
lg.Interpreter='latex';
lg.FontSize=15;
lg.Location='northwest';
xlim([-12.5,17.5])
ylim([12.5,50])
xlabel('$\Delta B^{\dagger}_{23}$ (mV)','Interpreter','latex','FontSize',22)
ylabel(['{\it{t}}_{23} (',char(181),'eV)'],'Interpreter','tex','FontSize',22);
%% Fig 4 b
data_exp_curve=importdata('fig_4_b\fig4_exp_curve_data.txt');
data_crosstalk=importdata('fig_4_b\t23_with_different_b34.txt');
x_data_combine=[];
y_data_combine=[];
figure
hold on
plt_obj_all=[];
for ii=1:6
    plt_obj=plot(data_exp_curve(:,1),transpose(data_crosstalk(ii,2:end)),'o','MarkerSize',5,'LineWidth',2);
    plt_obj.DisplayName=['$\Delta B^{\dagger}_{34}=$',num2str(-10+(ii-1)*4)];
    plt_obj_all=[plt_obj_all,plt_obj];
end
plt_obj_0=plot(data_exp_curve(:,1),data_exp_curve(:,2),'o','MarkerSize',5,'LineWidth',2,'Color','k');
plt_obj_0.DisplayName='$\Delta B^{\dagger}_{34}=$0';
for ii=1:6
    x_data_combine=[x_data_combine;data_exp_curve(:,1)];
    y_data_combine=[y_data_combine;transpose(data_crosstalk(ii,2:end))];
end
x_data_combine=[x_data_combine;data_exp_curve(:,1)];
y_data_combine=[y_data_combine;data_exp_curve(:,2)];
s = fitoptions('Method','NonlinearLeastSquares',...
    'Lower',[5,5,0],...
    'Upper',[40,40,15],...
    'Startpoint',[25,25,5]);
formula='a*exp((x)/b)+c';
f = fittype(formula,'dependent',{'y'},...
    'independent',{'x'},'coefficients',{'a','b','c'},'options', s);
gfit = fit(x_data_combine,y_data_combine,f);
data_combine_exp_fit_x=[-12.5:0.1:17.5];
data_combine_exp_fit=[data_combine_exp_fit_x;gfit.a*exp((data_combine_exp_fit_x)/gfit.b)+gfit.c];
data_combine_exp_fit=transpose(data_combine_exp_fit);
plot(data_combine_exp_fit(:,1),data_combine_exp_fit(:,2),':','LineWidth',2)
hold off
ax1=gca;
ax1.Box='on';
ax1.FontSize=20;
lg=legend([plt_obj_all(1:3),plt_obj_0,plt_obj_all(4:6)]);
lg.Interpreter='latex';
lg.FontSize=15;
lg.Location='northwest';
xlim([-12.5,17.5])
ylim([12.5,50])
xlabel('$\Delta B^{\dagger}_{23}$ (mV)','Interpreter','latex','FontSize',22)
ylabel(['{\it{t}}_{23} (',char(181),'eV)'],'Interpreter','tex','FontSize',22);