%% Fig S1
pat_data = importdata('fig_s1\pat_data.txt');
x_data=pat_data(:,2);
y_data=pat_data(:,1)/1e9;
z_data=pat_data(:,3);
dx=0.003;
dy=0.5;
x_edge=[min(x_data):dx:max(x_data)];
y_edge=[min(y_data):dy:max(y_data)];
[XX,YY]=meshgrid(x_edge,y_edge);
ZZ=griddata(x_data,y_data,z_data,XX,YY);
imagesc(x_edge,y_edge,ZZ)
set(gca,'YDir','normal')
hold on
xlim([-1,1])
ax1 = gca; % current axes
ax1.FontSize=20;
ax1.Position=[0.14, 0.185, 0.7661, 0.7];
box on
cb=colorbar;
cb.Ticks=[];
cb.Location='northoutside';
cb.Position=[0.7,0.9,0.2,0.05];
cb.Label.String='Processed signal';
cb.Label.Position=[-0.035,0,0];
xlabel('$\Delta P^{\prime}_1 = -\Delta P^{\prime}_2$ (mV)','Interpreter','latex','FontSize',22)
ylabel('Frequency (GHz)','FontSize',22)

% Find max & min
max_array=[];
min_array=[];
threshold=0.0057; % threshold for selecting max & min
for ii=1:0.5:30
    frequency=ii; % freqeucncy in GHz
    els=y_data>frequency-0.001&y_data<frequency+0.001;
    signal=[x_data(els),y_data(els),z_data(els)];
    [signal_max,idx_max]=max(signal(:,3));
    [signal_min,idx_min]=min(signal(:,3));
    if signal_max>threshold
        max_array=[max_array;[signal(idx_max,1),signal(idx_max,2)]];
    end
    if signal_min<-1*threshold
        min_array=[min_array;[signal(idx_min,1),signal(idx_min,2)]];
    end
end
detected_points=[max_array;min_array];

% remove points that are obviously off
els_off_1=detected_points(:,1)>-0.8&detected_points(:,1)<0.8;
detected_points=detected_points(els_off_1,:);
els_off_2=detected_points(:,2)>12;
detected_points=detected_points(els_off_2,:);
%plot(detected_points(:,1),detected_points(:,2),'.k')

% Fit to PAT
x = detected_points(:,1);
y = detected_points(:,2);
s = fitoptions('Method','NonlinearLeastSquares',...
    'Lower',[-0.2,20,150],...
    'Upper',[0.2,40,200],...
    'Startpoint',[0,32,175]);
formula='pat_function(x,x0,tc,la)';
f = fittype(formula,'dependent',{'y'},...
    'independent',{'x'},'coefficients',{'x0','tc','la'},'options', s);
gfit = fit(x,y,f);
plot(x_edge,pat_function(x_edge,gfit.x0,gfit.tc,gfit.la),'--','LineWidth',2,'Color','r')
%% Fig S2 a
start_target_final=importdata('fig_s2_a\start_target_final.txt');
sub_idx = [12,23,34];
figure
hold on
for ii=1:3
    plt = plot([1,2,3],start_target_final(ii,:),'.','MarkerSize',10);
    plt.DisplayName = ['$t_{',num2str(sub_idx(ii)),'}$'];
end
hold off
lg = legend;
lg.Interpreter='latex';
lg.Location='southeast';
ylabel('$t_{ij}$','Interpreter','latex','FontSize',22);
xticks([1 2 3])
xticklabels({'Initial','Target','Result'})
xlim([0.5,3.5])
ylim([20,35])
%% Fig S2 b
KT = 15.5; % temperature in ueV
tc_guess = [32,32,32]; % tunnel coupling in ueV
sub_idx = [12,23,34];
excess_charge_data={};
excess_charge_data{1} = importdata('fig_s2_b\excess_charge_t12.txt');
excess_charge_data{2} = importdata('fig_s2_b\excess_charge_t23.txt');
excess_charge_data{3} = importdata('fig_s2_b\excess_charge_t34.txt');
figure
hold on
for ii=1:3
    x = excess_charge_data{ii}(:,1);
    y = excess_charge_data{ii}(:,2);

    s = fitoptions('Method','NonlinearLeastSquares',...
        'Lower',[5,KT],...
        'Upper',[50,KT],...
        'Startpoint',[40,KT]);
    formula='excess_charge(x,tc,KT)';
    f = fittype(formula,'dependent',{'y'},...
        'independent',{'x'},'coefficients',{'tc','KT'},'options', s);
    gfit = fit(x,y,f);
    dot_plot = plot(x,y+(ii-1)*0.2,'.','MarkerSize',10);
    dot_plot.DisplayName=['$t_{',num2str(sub_idx(ii)),'}=',num2str(gfit.tc),'$'];
    fit_plot = plot(x,excess_charge(x,gfit.tc,KT)+(ii-1)*0.2,'k');
    set(fit_plot,'HandleVisibility','off')
end
hold off
xlim([-200,200])
lg = legend;
lg.Interpreter='latex';
lg.Location='Southeast';
xlabel(['Detuning, \epsilon (',char(181),'eV)'],'Interpreter','tex','FontSize',22)
ylabel('Excess charge','FontSize',22)
%% Fig S3 a
xy_data = importdata('fig_s3_a\t23_before_calibration.txt');
figure
hold on
plt_obj_all=[];
lin_fit_slope=[];
lin_fit_slope_error=[];
color_array=[0.85,0.325,0.098;0.93,0.694,0.125;0.494,0.184,0.557];
sub_idx_array=[12,23,34];
for ii=1:3
    x_data=xy_data(:,1);
    y_data=xy_data(:,ii+1);
    fit_result=polyfit(x_data,y_data,1);
    fit_line=x_data*fit_result(1)+fit_result(2);
    % calculate slope error
    data_number=length(x_data);
    x_data_mean=mean(x_data);
    tmp_1=(x_data-x_data_mean).^2;
    sum_tmp_1=sum(tmp_1);
    tmp_2=(y_data-fit_line).^2;
    sum_tmp_2=sum(tmp_2);
    slope_std_error=(sum_tmp_2/sum_tmp_1/(data_number-2))^0.5;
    
    lin_fit_slope=[lin_fit_slope,fit_result(1)];
    lin_fit_slope_error=[lin_fit_slope_error,slope_std_error];
    % filled marker
    plt_obj=plot(x_data,y_data,'o','MarkerSize',5,'LineWidth',2,'Color',color_array(ii,:),'MarkerFaceColor',color_array(ii,:));
    % unfilled marker
    %plt_obj=plot(x_data,y_data,'o','MarkerSize',5,'LineWidth',2,'Color',color_array(ii,:));

    plt_obj.DisplayName=['$B^{\prime}_{',num2str(sub_idx_array(ii)),'}$'];
    %plt_obj.DisplayName=['$B^{\dagger}_{',num2str(sub_idx_array(ii)),'}$'];
    plt_obj_all=[plt_obj_all,plt_obj];
    current_color=get(plt_obj,'Color');
    plot(x_data,fit_line,'--','LineWidth',2,'Color',current_color)
end
hold off
lg=legend(plt_obj_all);
lg.Interpreter='latex';
lg.FontSize=20;
lg.Orientation='horizontal';
lg.Location='northwest';
ax1 = gca; % current axes
ax1.FontSize=20;
box on
xlabel('$\Delta B^{\prime}_{ij}$ (mV)','Interpreter','latex','FontSize',22)
%xlabel('$\Delta B^{\dagger}_{ij}$ (mV)','Interpreter','latex','FontSize',22)
ylabel(['{\it{t}}_{23} (',char(181),'eV)'],'Interpreter','tex','FontSize',22);
%% Fig S3 b
xy_data = importdata('fig_s3_b\t23_after_calibration.txt');
figure
hold on
plt_obj_all=[];
lin_fit_slope=[];
lin_fit_slope_error=[];
color_array=[0.85,0.325,0.098;0.93,0.694,0.125;0.494,0.184,0.557];
sub_idx_array=[12,23,34];
for ii=1:3
    x_data=xy_data(:,1);
    y_data=xy_data(:,ii+1);
    fit_result=polyfit(x_data,y_data,1);
    fit_line=x_data*fit_result(1)+fit_result(2);
    % calculate slope error
    data_number=length(x_data);
    x_data_mean=mean(x_data);
    tmp_1=(x_data-x_data_mean).^2;
    sum_tmp_1=sum(tmp_1);
    tmp_2=(y_data-fit_line).^2;
    sum_tmp_2=sum(tmp_2);
    slope_std_error=(sum_tmp_2/sum_tmp_1/(data_number-2))^0.5;
    
    lin_fit_slope=[lin_fit_slope,fit_result(1)];
    lin_fit_slope_error=[lin_fit_slope_error,slope_std_error];
    % filled marker
    %plt_obj=plot(x_data,y_data,'o','MarkerSize',5,'LineWidth',2,'Color',color_array(ii,:),'MarkerFaceColor',color_array(ii,:));
    % unfilled marker
    plt_obj=plot(x_data,y_data,'o','MarkerSize',5,'LineWidth',2,'Color',color_array(ii,:));

    %plt_obj.DisplayName=['$B^{\prime}_{',num2str(sub_idx_array(ii)),'}$'];
    plt_obj.DisplayName=['$B^{\ast 1}_{',num2str(sub_idx_array(ii)),'}$'];
    plt_obj_all=[plt_obj_all,plt_obj];
    current_color=get(plt_obj,'Color');
    plot(x_data,fit_line,'--','LineWidth',2,'Color',current_color)
end
hold off
lg=legend(plt_obj_all);
lg.Interpreter='latex';
lg.FontSize=20;
lg.Orientation='horizontal';
lg.Location='northwest';
ax1 = gca; % current axes
ax1.FontSize=20;
box on
%xlabel('$\Delta B^{\prime}_{ij}$ (mV)','Interpreter','latex','FontSize',22)
xlabel('$\Delta B^{\ast 1}_{ij}$ (mV)','Interpreter','latex','FontSize',22)
ylabel(['{\it{t}}_{23} (',char(181),'eV)'],'Interpreter','tex','FontSize',22);
%% Fig S3 c
xy_data = importdata('fig_s3_c\t34_before_calibration.txt');
figure
hold on
plt_obj_all=[];
lin_fit_slope=[];
lin_fit_slope_error=[];
color_array=[0.85,0.325,0.098;0.93,0.694,0.125;0.494,0.184,0.557];
sub_idx_array=[12,23,34];
for ii=1:3
    x_data=xy_data(:,1);
    y_data=xy_data(:,ii+1);
    fit_result=polyfit(x_data,y_data,1);
    fit_line=x_data*fit_result(1)+fit_result(2);
    % calculate slope error
    data_number=length(x_data);
    x_data_mean=mean(x_data);
    tmp_1=(x_data-x_data_mean).^2;
    sum_tmp_1=sum(tmp_1);
    tmp_2=(y_data-fit_line).^2;
    sum_tmp_2=sum(tmp_2);
    slope_std_error=(sum_tmp_2/sum_tmp_1/(data_number-2))^0.5;
    
    lin_fit_slope=[lin_fit_slope,fit_result(1)];
    lin_fit_slope_error=[lin_fit_slope_error,slope_std_error];
    % filled marker
    plt_obj=plot(x_data,y_data,'o','MarkerSize',5,'LineWidth',2,'Color',color_array(ii,:),'MarkerFaceColor',color_array(ii,:));
    % unfilled marker
    %plt_obj=plot(x_data,y_data,'o','MarkerSize',5,'LineWidth',2,'Color',color_array(ii,:));

    %plt_obj.DisplayName=['$B^{\prime}_{',num2str(sub_idx_array(ii)),'}$'];
    plt_obj.DisplayName=['$B^{\ast 1}_{',num2str(sub_idx_array(ii)),'}$'];
    plt_obj_all=[plt_obj_all,plt_obj];
    current_color=get(plt_obj,'Color');
    plot(x_data,fit_line,'--','LineWidth',2,'Color',current_color)
end
hold off
lg=legend(plt_obj_all);
lg.Interpreter='latex';
lg.FontSize=20;
lg.Orientation='horizontal';
lg.Location='northwest';
ax1 = gca; % current axes
ax1.FontSize=20;
box on
%xlabel('$\Delta B^{\prime}_{ij}$ (mV)','Interpreter','latex','FontSize',22)
xlabel('$\Delta B^{\ast 1}_{ij}$ (mV)','Interpreter','latex','FontSize',22)
ylabel(['{\it{t}}_{34} (',char(181),'eV)'],'Interpreter','tex','FontSize',22);
%% Fig S3 d
xy_data = importdata('fig_s3_d\t34_after_calibration.txt');
figure
hold on
plt_obj_all=[];
lin_fit_slope=[];
lin_fit_slope_error=[];
color_array=[0.85,0.325,0.098;0.93,0.694,0.125;0.494,0.184,0.557];
sub_idx_array=[12,23,34];
for ii=1:3
    x_data=xy_data(:,1);
    y_data=xy_data(:,ii+1);
    fit_result=polyfit(x_data,y_data,1);
    fit_line=x_data*fit_result(1)+fit_result(2);
    % calculate slope error
    data_number=length(x_data);
    x_data_mean=mean(x_data);
    tmp_1=(x_data-x_data_mean).^2;
    sum_tmp_1=sum(tmp_1);
    tmp_2=(y_data-fit_line).^2;
    sum_tmp_2=sum(tmp_2);
    slope_std_error=(sum_tmp_2/sum_tmp_1/(data_number-2))^0.5;
    
    lin_fit_slope=[lin_fit_slope,fit_result(1)];
    lin_fit_slope_error=[lin_fit_slope_error,slope_std_error];
    % filled marker
    %plt_obj=plot(x_data,y_data,'o','MarkerSize',5,'LineWidth',2,'Color',color_array(ii,:),'MarkerFaceColor',color_array(ii,:));
    % unfilled marker
    plt_obj=plot(x_data,y_data,'o','MarkerSize',5,'LineWidth',2,'Color',color_array(ii,:));

    %plt_obj.DisplayName=['$B^{\prime}_{',num2str(sub_idx_array(ii)),'}$'];
    plt_obj.DisplayName=['$B^{\ast 2}_{',num2str(sub_idx_array(ii)),'}$'];
    plt_obj_all=[plt_obj_all,plt_obj];
    current_color=get(plt_obj,'Color');
    plot(x_data,fit_line,'--','LineWidth',2,'Color',current_color)
end
hold off
lg=legend(plt_obj_all);
lg.Interpreter='latex';
lg.FontSize=20;
lg.Orientation='horizontal';
lg.Location='northwest';
ax1 = gca; % current axes
ax1.FontSize=20;
box on
%xlabel('$\Delta B^{\prime}_{ij}$ (mV)','Interpreter','latex','FontSize',22)
xlabel('$\Delta B^{\ast 2}_{ij}$ (mV)','Interpreter','latex','FontSize',22)
ylabel(['{\it{t}}_{34} (',char(181),'eV)'],'Interpreter','tex','FontSize',22);
%% Fig S3 e
xy_data = importdata('fig_s3_e\t12_before_calibration.txt');
figure
hold on
plt_obj_all=[];
lin_fit_slope=[];
lin_fit_slope_error=[];
color_array=[0.85,0.325,0.098;0.93,0.694,0.125;0.494,0.184,0.557];
sub_idx_array=[12,23,34];
for ii=1:3
    x_data=xy_data(:,1);
    y_data=xy_data(:,ii+1);
    fit_result=polyfit(x_data,y_data,1);
    fit_line=x_data*fit_result(1)+fit_result(2);
    % calculate slope error
    data_number=length(x_data);
    x_data_mean=mean(x_data);
    tmp_1=(x_data-x_data_mean).^2;
    sum_tmp_1=sum(tmp_1);
    tmp_2=(y_data-fit_line).^2;
    sum_tmp_2=sum(tmp_2);
    slope_std_error=(sum_tmp_2/sum_tmp_1/(data_number-2))^0.5;
    
    lin_fit_slope=[lin_fit_slope,fit_result(1)];
    lin_fit_slope_error=[lin_fit_slope_error,slope_std_error];
    % filled marker
    plt_obj=plot(x_data,y_data,'o','MarkerSize',5,'LineWidth',2,'Color',color_array(ii,:),'MarkerFaceColor',color_array(ii,:));
    % unfilled marker
    %plt_obj=plot(x_data,y_data,'o','MarkerSize',5,'LineWidth',2,'Color',color_array(ii,:));

    %plt_obj.DisplayName=['$B^{\prime}_{',num2str(sub_idx_array(ii)),'}$'];
    plt_obj.DisplayName=['$B^{\ast 2}_{',num2str(sub_idx_array(ii)),'}$'];
    plt_obj_all=[plt_obj_all,plt_obj];
    current_color=get(plt_obj,'Color');
    plot(x_data,fit_line,'--','LineWidth',2,'Color',current_color)
end
hold off
lg=legend(plt_obj_all);
lg.Interpreter='latex';
lg.FontSize=20;
lg.Orientation='horizontal';
lg.Location='northwest';
ax1 = gca; % current axes
ax1.FontSize=20;
box on
%xlabel('$\Delta B^{\prime}_{ij}$ (mV)','Interpreter','latex','FontSize',22)
xlabel('$\Delta B^{\ast 2}_{ij}$ (mV)','Interpreter','latex','FontSize',22)
ylabel(['{\it{t}}_{12} (',char(181),'eV)'],'Interpreter','tex','FontSize',22);
%% Fig S3 f
xy_data = importdata('fig_s3_f\t12_after_calibration.txt');
figure
hold on
plt_obj_all=[];
lin_fit_slope=[];
lin_fit_slope_error=[];
color_array=[0.85,0.325,0.098;0.93,0.694,0.125;0.494,0.184,0.557];
sub_idx_array=[12,23,34];
for ii=1:3
    x_data=xy_data(:,1);
    y_data=xy_data(:,ii+1);
    fit_result=polyfit(x_data,y_data,1);
    fit_line=x_data*fit_result(1)+fit_result(2);
    % calculate slope error
    data_number=length(x_data);
    x_data_mean=mean(x_data);
    tmp_1=(x_data-x_data_mean).^2;
    sum_tmp_1=sum(tmp_1);
    tmp_2=(y_data-fit_line).^2;
    sum_tmp_2=sum(tmp_2);
    slope_std_error=(sum_tmp_2/sum_tmp_1/(data_number-2))^0.5;
    
    lin_fit_slope=[lin_fit_slope,fit_result(1)];
    lin_fit_slope_error=[lin_fit_slope_error,slope_std_error];
    % filled marker
    %plt_obj=plot(x_data,y_data,'o','MarkerSize',5,'LineWidth',2,'Color',color_array(ii,:),'MarkerFaceColor',color_array(ii,:));
    % unfilled marker
    plt_obj=plot(x_data,y_data,'o','MarkerSize',5,'LineWidth',2,'Color',color_array(ii,:));

    %plt_obj.DisplayName=['$B^{\prime}_{',num2str(sub_idx_array(ii)),'}$'];
    plt_obj.DisplayName=['$B^{\dagger}_{',num2str(sub_idx_array(ii)),'}$'];
    plt_obj_all=[plt_obj_all,plt_obj];
    current_color=get(plt_obj,'Color');
    plot(x_data,fit_line,'--','LineWidth',2,'Color',current_color)
end
hold off
lg=legend(plt_obj_all);
lg.Interpreter='latex';
lg.FontSize=20;
lg.Orientation='horizontal';
lg.Location='northwest';
ax1 = gca; % current axes
ax1.FontSize=20;
box on
%xlabel('$\Delta B^{\prime}_{ij}$ (mV)','Interpreter','latex','FontSize',22)
xlabel('$\Delta B^{\dagger}_{ij}$ (mV)','Interpreter','latex','FontSize',22)
ylabel(['{\it{t}}_{12} (',char(181),'eV)'],'Interpreter','tex','FontSize',22);